Module delta

Module delta 

Delta compression for collective sync.

Provides types and utilities for creating, compressing, and decompressing deltas that represent knowledge to be shared across codebases.

Structs

CollectiveDelta
A collective delta containing patterns and mistakes to share.
DeltaPattern
A pattern included in a collective delta.
MistakeReport
A report of a coding mistake or anti-pattern.

Enums

MistakeCategory
Category of mistake that can be reported.