Collective registry client.
Provides a registry client for querying and publishing collective intelligence data. Works in offline mode when no network is available.
Structs
- Collective
Cache - A TTL-based cache for collective data.
- Registry
Client - Registry client for collective intelligence data.
Enums
- Registry
Mode - Operating mode for the registry client.