Module impact

Module impact 

Enhanced Impact Analysis — Invention 1.

Trace forward through the dependency graph to predict ALL affected code before a change is made. Enriches the basic impact analysis with ProposedChange, ImpactType classification, BlastRadius, and Mitigations.

Structs

BlastRadius
Total blast radius of a change.
EnhancedImpactResult
Full enhanced impact analysis result.
ImpactAnalyzer
Analyzes the impact of proposed changes on the codebase.
ImpactedNode
A node impacted by a change.
Mitigation
A suggested mitigation.
ProposedChange
A proposed change to analyse.

Enums

ChangeType
Type of proposed change.
ImpactType
How a node is impacted.
RiskLevel
Risk level of the change.