Module incremental

Module incremental 

Incremental recompilation support.

Uses content hashing to detect which files have changed since the last compilation, then re-parses only those files and surgically updates the graph.

Structs

ChangeSet
Set of files that have changed since the last compilation.
IncrementalCompiler
Incremental compiler that tracks file content hashes to detect changes.
IncrementalResult
Result of an incremental recompilation.