pub enum ArchRule {
LayerDependency {
upper: String,
lower: String,
},
ModuleBoundary {
module: String,
},
NamingConvention {
prefix: String,
pattern: String,
},
Cyclic {
scope: String,
},
}Expand description
A single architectural rule.
Variants
LayerDependency
Layer A must not depend on Layer B.
ModuleBoundary
Module must not have external edges to another module.
NamingConvention
All units matching a prefix must follow a naming convention.
Cyclic
No dependency cycles in the given scope.