Module regression

Module regression 

Regression Oracle — Invention 3.

Predict which tests are likely to fail based on a change, before running them. Uses the code graph to trace from changed units to test units.

Structs

RegressionOracle
Prediction of test outcomes.
RegressionPredictor
Predicts test outcomes based on code changes.
TestId
Identifier for a test.
TestPrediction
A single test prediction.