Writes .acb files from a CodeGraph.
The writer serializes the graph into the binary .acb format:
header, unit table, edge table, compressed string pool, feature vectors,
temporal block, and index block.
Structs
- AcbWriter
- Writes
CodeGraphinstances to.acbbinary format.
Constants
- EDGE_
RECORD_ SIZE - Size of one edge record on disk (40 bytes).
- UNIT_
RECORD_ SIZE - Size of one code unit record on disk (96 bytes).