pub fn dfs(
graph: &CodeGraph,
start_id: u64,
options: &TraversalOptions,
) -> TraversalResultExpand description
Perform a depth-first traversal from the given start node.
Returns all reachable nodes with their distance from the start.
pub fn dfs(
graph: &CodeGraph,
start_id: u64,
options: &TraversalOptions,
) -> TraversalResultPerform a depth-first traversal from the given start node.
Returns all reachable nodes with their distance from the start.