Module truth

Module truth 

Truth Maintenance — Invention 6.

Track which claims have been invalidated by recent changes. Codebase changes; AI’s knowledge becomes stale.

Structs

MaintainedTruth
Record of a previously-true claim.
TruthInvalidation
Details about how a truth was invalidated.
TruthMaintainer
Maintains a set of truths and checks them against the current graph.

Enums

TruthStatus
Current status of a maintained truth.