pub struct TruthMaintainer<'g> { /* private fields */ }Expand description
Maintains a set of truths and checks them against the current graph.
Implementations
Sourceimpl<'g> TruthMaintainer<'g>
impl<'g> TruthMaintainer<'g>
Sourcepub fn register_truth(&mut self, claim: &str) -> MaintainedTruth
pub fn register_truth(&mut self, claim: &str) -> MaintainedTruth
Register a truth that should be maintained.
Sourcepub fn check_truth(&self, claim: &str) -> TruthStatus
pub fn check_truth(&self, claim: &str) -> TruthStatus
Check if a historical claim is still true against the current graph.
Sourcepub fn refresh_all(&mut self) -> Vec<MaintainedTruth>
pub fn refresh_all(&mut self) -> Vec<MaintainedTruth>
Refresh all maintained truths against the current graph.
Sourcepub fn truth_diff(&self) -> Vec<MaintainedTruth>
pub fn truth_diff(&self) -> Vec<MaintainedTruth>
Get a diff of what changed between two graph versions. Compares the current truth set status against the original.
Sourcepub fn truths(&self) -> &[MaintainedTruth]
pub fn truths(&self) -> &[MaintainedTruth]
Get all maintained truths.