Index by language.
Groups code units by their Language for fast filtered lookups.
Building the index is O(n); lookups are O(1).
Structs
- Language
Index - Index that groups code units by language.
Index by language.
Groups code units by their Language for fast filtered lookups.
Building the index is O(n); lookups are O(1).