pub struct JsonRpcResponse {
pub jsonrpc: String,
pub id: Value,
pub result: Option<Value>,
pub error: Option<JsonRpcError>,
}Expand description
JSON-RPC 2.0 response message.
Fields
jsonrpc: StringMust be “2.0”.
id: ValueMust match the request ID.
result: Option<Value>The result (present on success).
error: Option<JsonRpcError>The error (present on failure).
Implementations
Sourceimpl JsonRpcResponse
impl JsonRpcResponse
Sourcepub fn error(id: Value, error: JsonRpcError) -> Self
pub fn error(id: Value, error: JsonRpcError) -> Self
Create an error response.
Sourcepub fn tool_error(id: Value, message: impl Into<String>) -> Self
pub fn tool_error(id: Value, message: impl Into<String>) -> Self
Create a tool error response (isError: true per MCP spec).
Use this for tool execution failures instead of error().
Sourcepub fn into_tool_error_if_needed(self) -> Self
pub fn into_tool_error_if_needed(self) -> Self
If this is a JSON-RPC error response, convert it to a tool error (isError: true) per MCP spec. Protocol errors pass through unchanged.