pub struct Parser { /* private fields */ }Expand description
Main parser that orchestrates multi-language parsing.
Implementations
Sourceimpl Parser
impl Parser
Sourcepub fn parse_file(
&self,
path: &Path,
content: &str,
) -> AcbResult<Vec<RawCodeUnit>>
pub fn parse_file( &self, path: &Path, content: &str, ) -> AcbResult<Vec<RawCodeUnit>>
Parse a single file given its path and content.
Sourcepub fn parse_directory(
&self,
root: &Path,
options: &ParseOptions,
) -> AcbResult<ParseResult>
pub fn parse_directory( &self, root: &Path, options: &ParseOptions, ) -> AcbResult<ParseResult>
Parse all matching files in a directory tree.
Sourcepub fn should_parse(&self, path: &Path) -> bool
pub fn should_parse(&self, path: &Path) -> bool
Returns true if a file should be parsed based on language filters.