Core data types for the AgenticCodebase semantic code compiler.
This module contains all type definitions used throughout the system. No logic or I/O — pure struct definitions, enum definitions, and trait implementations.
Re-exports
pub use code_unit::CodeUnit;pub use code_unit::CodeUnitBuilder;pub use code_unit::CodeUnitType;pub use code_unit::Visibility;pub use edge::Edge;pub use edge::EdgeType;pub use error::AcbError;pub use error::AcbResult;pub use header::FileHeader;pub use language::Language;pub use span::Span;
Modules
- code_
unit - CodeUnit — the atomic element of the code graph.
- edge
- Edge types and structures for relationships between code units.
- error
- Error types for the AgenticCodebase system.
- header
- File header for the
.acbbinary format. - language
- Programming language detection and enumeration.
- span
- Source location types for tracking where code units appear in source files.
Constants
- ACB_
MAGIC - Magic bytes at the start of every .acb file: “ACDB”
- DEFAULT_
DIMENSION - Default feature vector dimensionality.
- FORMAT_
VERSION - Current format version.
- MAX_
DOC_ LENGTH - Maximum doc summary length.
- MAX_
EDGES_ PER_ UNIT - Maximum edges per code unit.
- MAX_
PATH_ LENGTH - Maximum file path length.
- MAX_
QUALIFIED_ NAME - Maximum qualified name length.
- MAX_
SIGNATURE_ LENGTH - Maximum signature length.
- MAX_
SYMBOL_ NAME - Maximum symbol name length.
Functions
- now_
micros - Returns the current time as Unix epoch microseconds.