CodeUnit — the atomic element of the code graph.
A code unit represents any identifiable piece of code: a function, class, module, import, test, or documentation block.
Structs
- Code
Unit - A single code unit — the atomic element of the code graph.
- Code
Unit Builder - Builder for constructing
CodeUnitinstances with optional fields.
Enums
- Code
Unit Type - The type of code unit stored in a node.
- Visibility
- Symbol visibility/accessibility.