Module error

Module error 

Error types for the AgenticCodebase system.

All errors are typed using thiserror and propagated through AcbResult.

Enums

AcbError
All error types that can occur in the AgenticCodebase system.

Type Aliases

AcbResult
Convenience result type for AgenticCodebase operations.