Delta compression for collective sync.
Provides types and utilities for creating, compressing, and decompressing deltas that represent knowledge to be shared across codebases.
Structs
- Collective
Delta - A collective delta containing patterns and mistakes to share.
- Delta
Pattern - A pattern included in a collective delta.
- Mistake
Report - A report of a coding mistake or anti-pattern.
Enums
- Mistake
Category - Category of mistake that can be reported.