Enhanced Impact Analysis — Invention 1.
Trace forward through the dependency graph to predict ALL affected code before a change is made. Enriches the basic impact analysis with ProposedChange, ImpactType classification, BlastRadius, and Mitigations.
Structs
- Blast
Radius - Total blast radius of a change.
- Enhanced
Impact Result - Full enhanced impact analysis result.
- Impact
Analyzer - Analyzes the impact of proposed changes on the codebase.
- Impacted
Node - A node impacted by a change.
- Mitigation
- A suggested mitigation.
- Proposed
Change - A proposed change to analyse.
Enums
- Change
Type - Type of proposed change.
- Impact
Type - How a node is impacted.
- Risk
Level - Risk level of the change.