Regression Oracle — Invention 3.
Predict which tests are likely to fail based on a change, before running them. Uses the code graph to trace from changed units to test units.
Structs
- Regression
Oracle - Prediction of test outcomes.
- Regression
Predictor - Predicts test outcomes based on code changes.
- TestId
- Identifier for a test.
- Test
Prediction - A single test prediction.