#[unsafe(no_mangle)]pub unsafe extern "C" fn acb_graph_free(graph: *mut c_void)Expand description
Free a graph handle.
Safety
graph must be a valid handle returned by acb_graph_open, or null.
Must not be called more than once for the same handle.