Truth Maintenance — Invention 6.
Track which claims have been invalidated by recent changes. Codebase changes; AI’s knowledge becomes stale.
Structs
- Maintained
Truth - Record of a previously-true claim.
- Truth
Invalidation - Details about how a truth was invalidated.
- Truth
Maintainer - Maintains a set of truths and checks them against the current graph.
Enums
- Truth
Status - Current status of a maintained truth.