EdgeType

Enum EdgeType 

#[repr(u8)]
pub enum EdgeType {
Show 18 variants Calls = 0, Imports = 1, Inherits = 2, Implements = 3, Overrides = 4, Contains = 5, References = 6, Tests = 7, Documents = 8, Configures = 9, CouplesWith = 10, BreaksWith = 11, PatternOf = 12, VersionOf = 13, FfiBinds = 14, UsesType = 15, Returns = 16, ParamType = 17,
}
The type of relationship between two code units.

Variants



Calls = 0

Runtime invocation: source calls target.



Imports = 1

Static dependency: source imports/uses target.



Inherits = 2

Type hierarchy: source extends/inherits target.



Implements = 3

Interface conformance: source implements target trait/interface.



Overrides = 4

Method override: source overrides target method.



Contains = 5

Structural containment: source contains target (module contains function).



References = 6

Non-call reference: source references target without calling.



Tests = 7

Test coverage: source test covers target code.



Documents = 8

Documentation: source doc describes target.



Configures = 9

Configuration: source configures target.



CouplesWith = 10

Hidden coupling: changes together >70% of time (from history).



BreaksWith = 11

Breaking relationship: changing source historically breaks target.



PatternOf = 12

Pattern instance: source is an instance of target pattern.



VersionOf = 13

Temporal: source is newer version of target.



FfiBinds = 14

Cross-language: source binds to target across FFI.



UsesType = 15

Type relationship: source uses target as a type.



Returns = 16

Return type: source returns target type.



ParamType = 17

Parameter type: source has parameter of target type.

Implementations

Source

impl EdgeType

pub const COUNT: usize = 18

The total number of edge type variants.

pub fn from_u8(value: u8) -> Option<Self>

Convert from raw byte value.

Returns None for values that don’t correspond to a known variant.

pub fn is_dependency(&self) -> bool

Returns true if this edge type indicates a dependency.

pub fn is_temporal(&self) -> bool

Returns true if this edge is derived from history analysis.

pub fn label(&self) -> &'static str

Returns a human-readable label for this edge type.